阿甘正传 (豆瓣)
Description: 阿甘正传电影简介和剧情介绍,阿甘正传影评、图片、预告片、影讯、论坛、在线购票
Keywords: 阿甘正传,Forrest Gump,阿甘正传影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.3豆瓣电影Top250

# 阿甘正传 Forrest Gump (1994)

更新描述或海报

导演: 罗伯特·泽米吉斯
编剧: 艾瑞克·罗斯 / 温斯顿·格鲁姆
主演: 汤姆·汉克斯 / 罗宾·怀特 / 加里·西尼斯 / 麦凯尔泰·威廉逊 / 莎莉·菲尔德 / 海利·乔·奥斯蒙 / 迈克尔·康纳·亨弗里斯 / 哈罗德·G·赫瑟姆 / 山姆·安德森 / 伊俄涅·M·特雷奇 / 彼得·道博森 / 希博汗·法隆 / 伊丽莎白·汉克斯 / 汉娜·豪尔 / 克里斯托弗·琼斯 / 罗布·兰德里 / 杰森·麦克奎尔 / 桑尼·施罗耶 / 艾德·戴维斯 / 丹尼尔C.斯瑞派克 / 大卫·布里斯宾 / 德博拉·麦克蒂尔 / 艾尔·哈林顿 / 阿非莫·奥米拉 / 约翰·沃德斯塔德 / 迈克尔·伯吉斯 / 埃里克·安德伍德 / 拜伦·明斯 / 斯蒂芬·布吉格沃特 / 约翰·威廉·高尔特 / 希拉里·沙普兰 / 伊莎贝尔·罗斯 / 理查德·达历山德罗 / 迪克·史迪威 / 迈克尔-杰斯 / 杰弗里·布莱克 / 瓦妮莎·罗斯 / 迪克·卡维特 / 马拉·苏查雷特扎 / 乔·阿拉斯奇 / W·本森·泰瑞
类型: 剧情 / 爱情
制片国家/地区: 美国
语言: 英语
上映日期: 1994-06-23(洛杉矶首映) / 1994-07-06(美国)
片长: 142分钟
又名: 福雷斯特·冈普
IMDb: tt0109830
豆瓣评分
引用
9.5
2055401人评价
5星
77.3%
4星
19.8%
3星
2.6%
2星
0.2%
1星
0.1%
好友评分
你关注的人看过这部作品的平均分
9.0
4人评价
好于 99% 剧情片
好于 99% 爱情片
我看过这部电影 2020-07-12 修改
我的评价:
推荐

## 阿甘正传的剧情简介 · · · · · ·

阿甘（汤姆·汉克斯 饰）于二战结束后不久出生在美国南方阿拉巴马州一个闭塞的小镇，他先天弱智，智商只有75，然而他的妈妈是一个性格坚强的女性，她常常鼓励阿甘“傻人有傻福”，要他自强不息。
阿甘像普通孩子一样上学，并且认识了一生的朋友和至爱珍妮（罗宾·莱特·潘 饰），在珍妮 和妈妈的爱护下，阿甘凭着上帝赐予的“飞毛腿”开始了一生不停的奔跑。
阿甘成为橄榄球巨星、越战英雄、乒乓球外交使者、亿万富翁，但是，他始终忘不了珍妮，几次匆匆的相聚和离别，更是加深了阿甘的思念。
有一天，阿甘收到珍妮的信，他们终于又要见面…… ©豆瓣

## 阿甘正传的演职员 · · · · · · ( 全部 59 )

- 罗伯特·泽米吉斯 导演
- 汤姆·汉克斯 饰 Forrest Gump
- 罗宾·怀特 饰 Jenny Curran
- 加里·西尼斯 饰 Lieutenant Dan Taylor
- 麦凯尔泰·威廉逊 饰 Bubba Blue
- 莎莉·菲尔德 饰 Mrs. Gump

## 阿甘正传的视频和图片 · · · · · · ( 预告片2 | 视频评论2 · 添加 | 图片891 · 添加 )

## 阿甘正传的获奖情况 · · · · · · ( 全部 )

- 第67届奥斯卡金像奖
- 最佳影片
- 史蒂夫·蒂彻 / 温迪·芬德曼 / 史蒂夫·斯达克

- 第52届金球奖
- 电影类 最佳剧情片

- 第48届英国电影学院奖
- 电影奖 最佳影片(提名)
- 温迪·芬德曼 / 史蒂夫·斯达克 / 史蒂夫·蒂彻 / 罗伯特·泽米吉斯

## 喜欢这部电影的人也喜欢 · · · · · ·

  肖申克的救赎

  当幸福来敲门

  三傻大闹宝莱坞

  摔跤吧！爸爸

  贫民窟的百万富翁

  荒岛余生

  心灵捕手

  国王的演讲

  死亡诗社

  美丽心灵

我要写短评

## 阿甘正传的短评 · · · · · · ( 全部 345351 条 )

热门 / 最新 / 好友

### 18164 有用 今天小熊不吃糖 看过 2008-08-12 06:12:09

羡慕珍妮，不管她多么叛逆、落魄、堕落，永远有阿甘在等她回来

### 2992 有用 亚比煞 看过 2008-06-16 09:25:37

他的十二支船，每一支都是她的名字。她走后，他只得跑遍世界的每一个湖泊和沙漠来思念她，只等她一声召唤便死心塌地的回到她的身边。好莱坞编造一个这么纯粹的故事，让我们看到我们所拥有的感情，是多么的残破不堪。这简直是残忍的，不道德的。

### 7711 有用 影志 看过 2006-02-13 02:13:17

妈妈说，生活就像一盒巧克力……请不要再续下一句，耳朵听的起了茧子。

### 3185 有用 陳 看过 2009-01-04 00:08:27

太甜美的美國夢

### 5754 有用 林愈静 看过 2006-04-21 21:00:17

每年看一遍，每年哭一遍，看看自己幸福还是阿甘幸福！时间：从2003开始每年一遍

> 更多短评 345351条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。

### 0 有用 CoCo陶可可 看过 2020-01-30 02:22:34

2020，03。

### 0 有用 LLudeer 看过 2013-12-15 16:05:50

超级喜欢的历史老师杨老师晚自习放给我们的~看完之后她的点评超精彩~

我要写影评

## 阿甘正传的影评 · · · · · · ( 全部 6573 条 )

热门 / 最新 / 好友
kino 2008-07-12 14:22:51

## 阿甘的爱情

一个南阿拉巴马州的傻子阿甘，一辈子喜欢的一个女人就是珍妮，从小到大阿甘和珍妮就是好朋友，他们一起上学，一起长大，最后虽然相隔很远但是阿甘始终爱着珍妮，不管她做什么，不管她是谁，不管她变得多老多丑，不管她身在何方，阿甘始终在哪个南阿拉巴马的家里，日夜思念他的... (展开)
10628 649 823回应 收起
山河大地 2005-06-13 18:18:47

## 飘飞的羽毛

常常和朋友们谈起阿甘。阿甘太运气了！朋友们总是这样说。我哑然。我很奇怪，阿甘坐在那张凳子上，难道只是在告诉来来往往的陌生人：“瞧，我多运气”？ 在好些年前，我曾对人生充满困惑。我不知道人活着为什么。有时候，我坐在窗台上，对自己说：我现在跳下去，与我活... (展开)
3574 278 293回应 收起
蹊默 2005-11-25 19:04:16

## 一羽人生

第一次看《阿甘正传》，我为片头和片尾的那片羽毛而困惑，导演以这片羽毛作为开幕式和闭幕式，究竟是在表现什么意思呢？想来想去，觉得羽毛像是阿甘的思绪，就没再深究下去了。今天看完之后，我强烈地感觉到一片飘到地上的羽毛就像一个降临到人世的生命，这片羽毛在广袤的... (展开)
3699 97 199回应 收起
阑珊 2009-11-29 15:30:36

## 经典重温！一定有你不知道的

这篇影评可能有剧透

1。阿甘和对丹中尉说自己要做船长时，丹中尉嘲笑说如果阿甘做了船长自己就会做太空人，这为以后也埋下了一个小伏笔，因为最后丹中尉的假腿就是用造航天飞机的材料做的。 2。阿甘最后和珍妮举行婚礼时，丹中尉是站在最后，其他人都是座着的。对于失去双腿的人，能够站立着就是... (展开)
2700 107 190回应 收起
楚荆 2007-10-07 11:54:18

## 天使之爱

jenny总是说，阿甘，你不懂什么是爱。 可是，我觉得他是最懂得什么是爱的人。 阿甘爱妈妈。 当然，他的妈妈也确确实实是一位伟大的母亲。她用她的整个生命来爱自己的儿子，从不因为阿甘智力上的残缺而吝啬他应得的那份爱。她让阿甘一直成长得很开心，也因为这样，阿甘才能拥有... (展开)
1871 59 167回应 收起
碎岁 2010-10-14 09:50:20

## 为什么必须要给大众趣味一记耳光

这篇影评可能有剧透

为什么必须要给大众趣味一记耳光 文/碎岁 我历来对那些什么男人必看十大电影，人生要读的50部书一类单子深恶痛绝，觉得是一种文化强权，于是一直抵制，当然，这是一种偏执的较劲，作品只是被舆论绑架而已，让它们作牺牲品，何其无辜？而我何必因此错过可能的佳作？但每当我想从... (展开)
1814 1332 891回应 收起
青树夏日 2009-01-20 13:25:04

## 看阿甘之前，一定要了解的……

花絮： •比尔•默里曾被考虑出演阿甘。 •拍摄时Gary Sinise(丹中尉)的腿是用蓝布包着的，这样在后期制作时可以用电脑去除。 •片中汤姆•汉克斯忘我地长跑时，他的弟弟吉姆经常在旁边伴跑。 •汤姆•汉克斯演阿甘时模仿了饰演小阿甘的Michael Conner Humph... (展开)
539 24 42回应 收起
工藤新一的猴子 2017-03-24 16:35:31

## 阿甘的珍妮——永远的珍妮

看到一些对《阿甘正传》中珍妮的质疑和非议，觉得有些遗憾。对于一个真实的珍妮，不能用简单片面的是与非，对与错，爱与不爱去判定，而是用一种更加宽容体谅的态度去给她一个客观全面的分析和公正。 1、阿甘的天使 对阿甘起到重要积极作用的其实就是两个女人，一个是他的母亲，... (展开)
578 9 81回应 收起
le frisson™ 2005-08-29 09:39:26

## seeds of a conservative revival

大二的时候，和一个alpha female谈起阿甘。她一脸鄙视：你还认为阿甘是白痴阿？ 　　 　　我点头。 　　 　　好莱坞的聪明人把阿甘送上神坛，好像动机太过明显。表面上说圣洁的白痴（holy idiot）总可以逢凶化吉，老掉牙的motif，不过很有趣地用在风起云涌的革命年代，越战... (展开)
376 162 130回应 收起
柏邦妮 2006-11-06 13:42:12

## 巧克力的骗局

长大了，觉得好莱坞不好玩了。 大概是因为，总能从看起来很娱乐，很简单的电影里面，读出其他东西吧？ 那些东西使我不快。 很多感动过我的东西，也已经变质了。 比如说，再看《沉默的羔羊》， 已经不再觉得朱迪 福斯特是一个坚毅智慧的女英雄。 女人从来不是好莱坞电影行动的主... (展开)
254 41 42回应 收起

> 更多影评 6573篇

添加新讨论

## 讨论区 · · · · · ·

乒乓外交碍着谁了？为什么要删掉 | 来自黎 何 段 程 | 2 回应 | 2022-11-21 23:01:28
多年后再次看影片，特别是对Jenny有很多东西有了不... | 来自佳佳 | 8 回应 | 2022-11-17 23:39:53
阿甘正传有多少镜头 | 来自dog |  | 2022-11-16 22:44:26
想看 | 来自Lly | 1 回应 | 2022-11-16 22:39:57
run | 来自。 |  | 2022-11-14 22:38:38

> 去这部影片的讨论区（全部1231条）

## 关于《阿甘正传》的问题 · · · · · · ( 全部50个 )

- 阿甘是不是喜当爹了？ 17人回答
- Jenny为什么恨她老爸啊？？ 7人回答

> 全部50个问题

## 在哪儿看这部电影 · · · · · ·

报错

- 咪咕视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 优酷视频 VIP免费观看
- 西瓜视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【内牛满面】 (影志)
- 【励志电影】 (影志)
- 电影学院本科生必看100部 (志国)
- {北美电影票房总排行} (荔枝超人)

## 谁在看这部电影 · · · · · ·

- 清奈
  刚刚 看过
- 剁姜💦
  1分钟前 看过
- 峰峰
  3分钟前 看过

3685397人看过 / 345100人想看

订阅阿甘正传的评论:
feed: rss 2.0